--- meta: title: Spacing Tokens description: Spacing tokens are used to provide consistent spacing between content in your app. --- # Spacing Tokens Spacing tokens are used to provide consistent spacing between content in your app. | Token | Value | Example | | -------------------------- | -------------- | --------------------------------------------------------------------------------------------------------------------- | | `--terra-spacing-3x-small` | 0.125rem (2px) |
| | `--terra-spacing-2x-small` | 0.25rem (4px) |
| | `--terra-spacing-x-small` | 0.5rem (8px) |
| | `--terra-spacing-small` | 0.75rem (12px) |
| | `--terra-spacing-medium` | 1rem (16px) |
| | `--terra-spacing-large` | 1.25rem (20px) |
| | `--terra-spacing-x-large` | 1.75rem (28px) |
| | `--terra-spacing-2x-large` | 2.25rem (36px) |
| | `--terra-spacing-3x-large` | 3rem (48px) |
| | `--terra-spacing-4x-large` | 4.5rem (72px) |
|